From ebbb2280db83a859f26a2f2dc0252e4d6e316452 Mon Sep 17 00:00:00 2001
From: Florian Schmaus <flo@geekplace.eu>
Date: Thu, 21 Nov 2024 17:46:57 +0100
Subject: [PATCH] pyproject.toml: explicitly set build-backend

Prior to this change, pyproject.toml would not set an build-backend,
while the project also has no setup.py.

According to some experts from Gentoo's Python project, this is a
violation of PEP 517, which states

"""
If the pyproject.toml file is absent, or the build-backend key is
missing, the source tree is not using this specification, and tools
should revert to the legacy behaviour of running setup.py (either
directly, or by implicitly invoking the setuptools.build_meta:__legacy__ backend).
"""

However, the project has no setup.py to invoke, hence Gentoo's
infrastructor for building Python packages fails without the
build-backend key being set.
---
 pyproject.toml | 1 +
 1 file changed, 1 insertion(+)

diff --git a/pyproject.toml b/pyproject.toml
index 989939e..9b63039 100644
--- a/pyproject.toml
+++ b/pyproject.toml
@@ -1,5 +1,6 @@
 [build-system]
 requires = ['setuptools']
+build-backend = "setuptools.build_meta"
 
 
 [project]
